==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/GetExpressRouteCircuitAuthorizationResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Authorization in an ExpressRouteCircuit resource.
 * @property authorizationKey The authorization key.
 * @property authorizationUseStatus The authorization use status.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property provisioningState The provisioning state of the authorization resource.
 * @property type Type of the resource.
 */
public data class GetExpressRouteCircuitAuthorizationResult(
    public val authorizationKey: String? = null,
    public val authorizationUseStatus: String? = null,
    public val etag: String,
    public val id: String? = null,
    public val name: String? = null,
    public val provisioningState: String,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.GetExpressRouteCircuitAuthorizationResult):
            GetExpressRouteCircuitAuthorizationResult = GetExpressRouteCircuitAuthorizationResult(
            authorizationKey = javaType.authorizationKey().map({ args0 -> args0 }).orElse(null),
            authorizationUseStatus = javaType.authorizationUseStatus().map({ args0 -> args0 }).orElse(null),
            etag = javaType.etag(),
            id = javaType.id().map({ args0 -> args0 }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            provisioningState = javaType.provisioningState(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/GetExpressRouteCircuitAuthorizationResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Authorization in an ExpressRouteCircuit resource.
 * @property authorizationKey The authorization key.
 * @property authorizationUseStatus The authorization use status.
 * @property etag A unique read-only string that changes whenever the resource is updated.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within a resource group. This name can be used to access the resource.
 * @property provisioningState The provisioning state of the authorization resource.
 * @property type Type of the resource.
 */
public data class GetExpressRouteCircuitAuthorizationResult(
    public val authorizationKey: String? = null,
    public val authorizationUseStatus: String? = null,
    public val etag: String,
    public val id: String? = null,
    public val name: String? = null,
    public val provisioningState: String,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.GetExpressRouteCircuitAuthorizationResult): GetExpressRouteCircuitAuthorizationResult = GetExpressRouteCircuitAuthorizationResult(
            authorizationKey = javaType.authorizationKey().map({ args0 -> args0 }).orElse(null),
            authorizationUseStatus = javaType.authorizationUseStatus().map({ args0 -> args0 }).orElse(null),
            etag = javaType.etag(),
            id = javaType.id().map({ args0 -> args0 }).orElse(null),
            name = javaType.name().map({ args0 -> args0 }).orElse(null),
            provisioningState = javaType.provisioningState(),
            type = javaType.type(),
        )
    }
}
